# Webware for Python 3

Webware for Python is a well-proven and platform-independent suite of Python packages and tools for developing object-oriented, web-based applications. The suite uses well known design patterns and includes Servlets, Python Server Pages (PSP), Task Scheduling, Session Management, and many other features. Webware is very modular and easily extended.

Webware for Python 3 is the latest version of the suite, which has been adapted to use Python 3 instead of Python 2 and the WSGI standard instead of the custom Webware threaded application server and various adapters, but otherwise kept compatible with the legacy version.

The current project **homepage** can be found here: <https://github.com/WebwareForPython/w4py3>

The current **documentation** is published at: <https://webwareforpython.github.io/w4py3/>

You can still find the **legacy version** of Webware for Python at: <https://webwareforpython.github.io/w4py/>
